@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from django.apps import AppConfig
 
 
@@ -7,5 +6,5 @@ class BadgifyConfig(AppConfig):
     verbose_name = 'Badgify'
 
     def ready(self):
-        super(BadgifyConfig, self).ready()
+        super().ready()
         self.module.autodiscover()
