@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import logging
 
 logger = logging.getLogger('badgify')
@@ -30,7 +27,7 @@ class BadgifyRegistry(object):
         """
         Returns registered recipes list (badge slugs).
         """
-        return self._registry.keys()
+        return list(self._registry.keys())
 
     def register(self, recipe):
         """
@@ -121,14 +118,24 @@ class BadgifyRegistry(object):
 def _autodiscover(recipes):
     import copy
     from django.conf import settings
-    from django.utils.importlib import import_module
+
+    try:
+        # py27 / py3 only
+        from importlib import import_module
+    except ImportError:
+        from django.utils.importlib import import_module
+
     from django.utils.module_loading import module_has_submodule
+
     for app in settings.INSTALLED_APPS:
+        if app.startswith("badgify"):
+            continue
+
         mod = import_module(app)
         try:
             before_import_recipes = copy.copy(recipes)
             import_module('%s.badgify_recipes' % app)
-        except:
+        except Exception:
             recipes = before_import_recipes
             if module_has_submodule(mod, 'badgify_recipes'):
                 raise
