@@ -4,10 +4,12 @@ from django import template
 from ..models import Badge, Award
 from ..compat import get_user_model
 
+
 register = template.Library()
+register_tag = register.assignment_tag if hasattr(register, 'assignment_tag') else register.simple_tag
 
 
-@register.assignment_tag
+@register_tag
 def badgify_badges(**kwargs):
     """
     Returns all badges or only awarded badges for the given user.
@@ -21,7 +23,7 @@ def badgify_badges(**kwargs):
         except User.DoesNotExist:
             pass
     if user:
-        awards = Award.objects.filter(user=user)
+        awards = Award.objects.filter(user=user).select_related('badge')
         badges = [award.badge for award in awards]
         return badges
     return Badge.objects.all()
